--[[ Copyright (c) 2015 Bruce Hill <bruce@bruce-hill.com>
     This work is free. You can redistribute it and/or modify it under the
     terms of the Do What The Fuck You Want To Public License, Version 2,
     as published by Sam Hocevar. See the COPYING file for more details.]]
local Camera = require 'camera'

function love.load()
    dots = {}; for i=1,100 do dots[i] = {x=math.random(1000), y=math.random(1000)} end
    camera = Camera:new(dots[1].x, dots[1].y)
end

function love.draw()
    -- Draw world objects
    camera:set()
    for i, dot in ipairs(dots) do
        love.graphics.setColor(((i*0.61803398875)%1)*255,0,255) -- Magic unique color per dot
        love.graphics.circle('fill',dot.x,dot.y,20)
    end
    camera:unset()
    camera.shake = camera.shake * .9

    -- Draw UI
    love.graphics.setColor(255,0,0)
    love.graphics.circle('line',.5*love.graphics.getWidth(),.5*love.graphics.getHeight(),15)
end

function love.mousepressed(x,y,button)
    -- Scroll for zooming
    if button == 'wu' then
        camera.scale = camera.scale / 1.1
    elseif button == 'wd' then
        camera.scale = camera.scale * 1.1
    -- Left click starts a drag, everything else does nothing.
    elseif button ~= 'l' then return end
    -- Set where the camera is zooming/scrolling relative to.
    camera.target.screenX, camera.target.screenY = x, y
    camera.target.prevScreenX, camera.target.prevScreenY = x, y
end

function love.mousemoved(x,y,dx,dy)
    -- Drag the camera around with left click.
    if love.mouse.isDown('l') then
        camera.target.screenX, camera.target.screenY = x, y
    end
end

function love.keypressed(key)
    -- Focus the camera on a random dot
    if key == 'r' then
        local r = dots[math.random(#dots)]
        camera:moveTo(r.x, r.y)
    -- Shake the camera
    elseif key == ' ' then
        camera.shake = camera.shake + 16
    end
end
